==> monodevelop_2.0%2Bdfsg.orig.tar.gz: monodevelop-2.0/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Gui.Content/IEditableTextBuffer.cs <==
//
// IEditableTextBuffer.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Projects.Text;

namespace MonoDevelop.Ide.Gui.Content
{
	public interface IEditableTextBuffer : ITextBuffer, IEditableTextFile
	{	
		bool EnableUndo {
			get;
		}
		bool EnableRedo {
			get;
		}
		
		void SetCaretTo (int line, int column);
		
		void Undo();
		void Redo();
		
		void BeginAtomicUndo ();
		void EndAtomicUndo ();
		
		event EventHandler CaretPositionSet;
		event EventHandler<TextChangedEventArgs> TextChanged;
	}
	
	public class TextChangedEventArgs : System.EventArgs
	{
		int startIndex;
		public int StartIndex {
			get { 
				return startIndex; 
			}
		}
		
		int endIndex;
		public int EndIndex {
			get { 
				return endIndex; 
			}
		}
		
		public TextChangedEventArgs (int startIndex, int endIndex)
		{
			this.startIndex = startIndex;
			this.endIndex   = endIndex;
		}
	}
}

==> monodevelop_3.0.2%2Bdfsg.orig.tar.gz: monodevelop-3.0.2/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Gui.Content/IEditableTextBuffer.cs <==
//
// IEditableTextBuffer.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Projects.Text;

namespace MonoDevelop.Ide.Gui.Content
{
	public interface IEditableTextBuffer : ITextBuffer, IEditableTextFile, IUndoHandler
	{	
		int LineCount { get; }
		void SetCaretTo (int line, int column);
		void SetCaretTo (int line, int column, bool highlightLine);
		void SetCaretTo (int line, int column, bool highlightLine, bool centerCaret);
		bool HasInputFocus { get; }
		
		event EventHandler CaretPositionSet;
		event EventHandler<TextChangedEventArgs> TextChanged;
	}
	
	public class TextChangedEventArgs : System.EventArgs
	{
		int startIndex;
		public int StartIndex {
			get { 
				return startIndex; 
			}
		}
		
		int endIndex;
		public int EndIndex {
			get { 
				return endIndex; 
			}
		}
		
		public TextChangedEventArgs (int startIndex, int endIndex)
		{
			this.startIndex = startIndex;
			this.endIndex   = endIndex;
		}
	}
}
